#
# spec file for package python-sphinx-click
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sphinx-click
Version:        6.0.0
Release:        1.2
Summary:        Sphinx extension that automatically documents click applications
License:        MIT
URL:            https://github.com/stephenfin/sphinx-click
Source:         https://files.pythonhosted.org/packages/source/s/sphinx_click/sphinx_click-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
BuildRequires:  python-rpm-generators
%{?python_enable_dependency_generator}
%python_subpackages

%description
A Sphinx plugin that allows to automatically extract documentation from click-based applications and include it in documentation.

%prep
%autosetup -p1 -n sphinx_click-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%{python_sitelib}/sphinx_click
%{python_sitelib}/sphinx_click-%{version}.dist-info

%changelog
* Mon Jul  1 2024 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * FIX Format string defaults correctly
  * Remove errant prints
  * Drop support for click 7.x, Sphinx < 5.x
  * readthedocs: Use dirhtml builder
  * docs: Add discrete mocking section
  * actions: Integrate tox-gh-actions
  * Distinguish between click and asyncclick
  * tests: Set maxDiff
  * Skip test with click 7.x
  * FIX If the \`help\` of an argument is \`None\`, don't fail
  * Add defusedxml to tox deps
  * Add defusedxml as test requirement
  * typing: Remove unused ignore
  * Add readthedocs config file
  * Fix show\_default with context\_settings
  * tests: Add tests for 'commands' option
  * Add support, testing for Python 3.12
  * Add release note for typer arg help text feature
  * Interpret help for arguments
  * typing: Update for latest types-docutils
* Wed Nov 22 2023 Dirk Müller <dmueller@suse.com>
- update to 5.1.0:
  * tox: Remove py37 entries
  * Add support for mocking modules
  * docs: Fix indentation
  * setup: Add Sphinx classifier
* Wed Sep 13 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Fix compatibility with Sphinx 7.2.x
  * Add release note for events support
  * Process events
  * Add release note for end of Python 3.7 support
  * setup.cfg: Add click keyword
  * Drop Python 3.7 support
* Thu May 11 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Add release note for Python 3.11 support
  * actions: Test Python 3.11
  * Points to alternative to complement Click-based CLI documentation
  * Add Sphinx extension classifier
  * Add pull request template
  * Trivial setup.py, setup.cfg changes
  * Render option defaults as literals
  * Change target Python version used for black
  * actions: Update to latest versions of actions
  * Use deep clone for GitHub actions
  * docs: Add more examples
  * tests: Add more application tests
  * Add our first "extension" test
  * Switch to pytest for testing
  * Run mypy as part of CI job
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.3.0
  * Fix typo
  * Add release note for auto_envvar_prefix support
  * add functionality to also render env-variables that are created via the ‘auto_envvar_prefix’ option
- Update to version 4.2.0
  * Extend pre-wrapped text support to options
  * tests: Use Command tests, not Group tests
  * tests: Add test for boolean options
- Update to version 4.1.0
  * docs: Don’t recommend using ‘setup.py’
  * docs: Indicate support for asyncclick
  * asyncclick target
  * docs: Remove ‘language’ configuration
  * docs: Add root directory to PATH for docs build
  * docs: Remove noise from conf.py
  * tox: Enable nitpicky mode for docs builds
- Update to version 4.0.3
  * Correct ‘get_command’ argument type error
- Update to version 4.0.2
  * Correctly ignore empty ‘commands’ parameter
- Update to version 4.0.1
  * docs: Correct typo
  * Configure mypy
  * Add typing hints
  * Pass Context, not self, to MultiCommand
  * Add test for truncation
- Update to version 4.0.0
  * Add Python 3.10 support, drop Python 3.6 support
  * Uncap coverage, remove test-requirements.txt
  * Update pre-commit hooks
  * Add support for click 8.1.x
  * setup: Update URL
* Sat Mar 26 2022 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial package for version 3.1.0.
